/*================================================================== 
 * Licensed Materials - Property of IBM 
 * IBM SecureWay On Demand Client/Server 
 * (c) Copyright IBM Corp. 1999  All rights reserved. 
 * 
 * US Government Users Restricted Rights - Use, duplication or 
 * disclosure restricted by GSA ADP Schedule Contract with IBM 
 * Corp. 
 * 
 * DISCLAIMER OF WARRANTIES.  The following [enclosed] code is 
 * sample code created by IBM Corporation.  This sample code is 
 * not part of any standard or IBM product and is provided to you 
 * solely for the purpose of assisting you in the development of 
 * your applications.  The code is provided "AS IS", without 
 * warranty of any kind.  IBM shall not be liable for any damages 
 * arising out of your use of the sample code, even if they have 
 * been advised of the possibility of such damages. 
 ******************************************************************** 
 * MessageNow.java
 *
 * Demo: Pager Messaging 
 *
 * Purpose:
 * Client User Interface class for Message Demo
 *
 ******************************************************************** 
 * Change History: 
 ******************************************************************** 
 * 
 *  REASON   DATE     ORIGIN     DESCRIPTION 
 *  -------- ------   ------     ----------- 
 *  new      052599   Steve Ims  New code 
 *===================================================================*/ 

package Demos.MessageDemo.MessageNow;

import java.awt.*;
import java.awt.event.*;
import java.io.*;
import java.net.*;
import java.util.*;

import javax.swing.*;

import com.ibm.managed.preference.*;
import com.ibm.managed.resource.*;
import com.ibm.managed.security.*;
import com.ibm.managed.security.client.*;

import com.ms.security.*;  
import netscape.security.*;


import Demos.MessageDemo.MessageServer.client.*;


/**
 * <p> This JApplet provides the client user interface for the messaging demo.  
 * It presents two drop down lists, which allow the user to specify individual
 * users, groups of users, or combinations of the two as the recipients of a 
 * message.
 * 
 * <hr>
 * 
 * <p> There are two aspects of this class that would be of interest to new
 * On Demand Server Programmers:
 * <ul>
 * 	<li> The use of the On-Demand Server <b>PreferenceContext</b> class to 
 * 		 force the applet user to login
 * 	<li> The use of a servlet running as an Administrator to provide a 
 * 		 controlled access to certain information (in this a case a listing
 * 		 of all the users and user groups ), which ordinary users would not
 * 		 have access to.
 * </ul>
 * 
 * @author Steve Ims
 * @see MessageClient
 * @see MessageServer
 * @see UserProfile
 */
public class MessageNow extends JApplet implements ActionListener
{     
    public final static String ADMIN_SERVER_SERVLET_URL
        = "/servlet/Demos.MessageDemo.MessageNow.AdminServer";
        
    private JComboBox        cbUsers        = new JComboBox();
    private JComboBox        cbGroups       = new JComboBox();
    private JButton          bRemove        = new JButton(" Remove ");
    private JButton          bSend          = new JButton(" Send Message ");
    private JTextArea        taMessage      = new JTextArea(5, 30);
    private JScrollPane      spMessage      = new JScrollPane(taMessage);
    private DefaultListModel dlmRecipients  = new DefaultListModel();
    private JList            lRecipients    = new JList(dlmRecipients);
    private JScrollPane      spRecipients   = new JScrollPane(lRecipients);

    private JPanel p1 = new JPanel();
    private JPanel p2 = new JPanel();
    private JPanel p3 = new JPanel();
    private JPanel p4 = new JPanel();
    private JPanel p5 = new JPanel();

    private GridBagLayout      g = new GridBagLayout();
    private GridBagConstraints c = new GridBagConstraints();

    final static String USER_TAG  = "User: ";
    final static String GROUP_TAG = "Group: ";

    /*
     * Class that encapsulates network communication with MessageServer Servlet
     */
    MessageClient _messageClient;


    /**
     * Forces the user to login to On Demand Server if they have not already done
     * so.  Builds the simple GUI.
     *
     */
    public void start() {
        try {
            // Netscape permissions
            PrivilegeManager.enablePrivilege("UniversalConnect");
            
            // IE permissions
            PolicyEngine.assertPermission(PermissionID.NETIO); 
            
            // Force login
            // If a user has not already logged in, the following three
            //  lines of code will force he or she to do so.
            PreferenceContext userPrefContext 
                = PreferenceContext.getInitialContext("/");
            PreferenceSet prefs = new PreferenceSet();
            prefs.load(userPrefContext);

            // Create the MessageClient for handling message posting.
            // The MessageClient encapsulates all of the network communication
            //  with the MessageServer Servlet
            URL codeBase   = getCodeBase();
            _messageClient = new MessageClient(codeBase.getHost(),
                                               codeBase.getPort());

            // Build the gui
            createPanel();

        } catch(Exception x) {
            x.printStackTrace();
        }
    }   


    /**
     * Builds a simple GUI that allows a user to specify individual
     * users, entire groups, or comibinations of the two as the 
     * recipients of a short message.
     * 
     * <p>The first combo box, labeled "Users", contains a list of all
     * of the users available to send a message to.  The second
     * combo box lists all of the groups that a message can be sent
     * to.  These lists are obtained via a call to 
     * <em> getListFromAdminServer </em>.
     * 
     * @exception java.lang.Exception
     */
    void createPanel() 
        throws Exception
    {
        getContentPane().setLayout(g);

        cbUsers.addItem("Users");

        // Obtain list of all users from AdminServer Servlet
        Vector vUsers = getListFromAdminServer(AdminServer.ALL_USERS);
        
        Enumeration users = vUsers.elements();
        while(users.hasMoreElements()) {
            // Because r1 came from a call to list(), it cannot be used for
            // delete or modify operations.
            Resource r1 = (Resource) users.nextElement();
            cbUsers.addItem(r1.getName());
        }
 

        p1.add(cbUsers);
        c.gridx = 0;
        c.gridy = 0;
        g.setConstraints(p1, c);
        getContentPane().add(p1);
        cbUsers.addActionListener(this);


        cbGroups.addItem("Groups");

        // Obtain list of all users from AdminServer Servlet
        //  This is how we get information that an ordinary user
        //  does not have direct access to
        Vector vGroups = getListFromAdminServer(AdminServer.ALL_USER_GROUPS);
        
        Enumeration groups = vGroups.elements();
        while(groups.hasMoreElements()) {
            // Because r1 came from a call to list(), it cannot be used for
            // delete or modify operations.
            Resource r1 = (Resource) groups.nextElement();
            cbGroups.addItem(r1.getName());
        }

        p2.add(cbGroups);
        c.gridx = 0;
        c.gridy = 1;
        g.setConstraints(p2, c);
        getContentPane().add(p2);
        cbGroups.addActionListener(this);

        p3.setLayout(new BoxLayout(p3, BoxLayout.Y_AXIS));
        p3.add(spRecipients);
        p3.add(bRemove);
        bRemove.setEnabled(false);
        bRemove.setAlignmentX(Component.CENTER_ALIGNMENT);
        bRemove.setAlignmentY(Component.CENTER_ALIGNMENT);
        p3.setBorder(BorderFactory.createTitledBorder("Recipient List"));
        c.gridx = 1;
        c.gridy = 0;
        c.gridheight = 2;
        c.gridwidth  = 1;
        g.setConstraints(p3, c);
        getContentPane().add(p3);
        bRemove.addActionListener(this);

        taMessage.setLineWrap(true);
        spMessage.setVerticalScrollBarPolicy(JScrollPane.VERTICAL_SCROLLBAR_ALWAYS);
        p4.add(spMessage);
        p4.setBorder(BorderFactory.createTitledBorder(BorderFactory.createEmptyBorder(), "Message:"));
        c.gridx = 0;
        c.gridy = 2;
        c.gridheight = 1;
        c.gridwidth  = 2;
        g.setConstraints(p4, c);
        getContentPane().add(p4);

        p5.add(bSend);
        c.gridx = 0;
        c.gridy = 3;
        c.gridheight = 1;
        c.gridwidth  = 2;
        g.setConstraints(p5, c);
        getContentPane().add(p5);
        bSend.addActionListener(this);
    } // end of createPanel()


    /**     
     *
     */
    public void actionPerformed(ActionEvent ae) 
    {
        // A user has been selected from Users Combo Box
        if(ae.getSource() == cbUsers) {
            if(cbUsers.getSelectedIndex() == 0) {
                return;
            }

            dlmRecipients.addElement(USER_TAG + cbUsers.getSelectedItem());
            cbUsers.setSelectedIndex(0);
            bRemove.setEnabled(true);

        // A Group has been selected from Groups Combo Box
        } else if(ae.getSource() == cbGroups) {
            if(cbGroups.getSelectedIndex() == 0) {
                return;
            }

            dlmRecipients.addElement(GROUP_TAG + cbGroups.getSelectedItem());
            cbGroups.setSelectedIndex(0);
            bRemove.setEnabled(true);

        // Users/Groups have been removed from recipient list
        } else if(ae.getSource() == bRemove) {
            int[] indices = lRecipients.getSelectedIndices();
            for (int i = indices.length - 1; i >= 0; i--) {
                dlmRecipients.removeElementAt(indices[i]);
            }
            bRemove.setEnabled(!dlmRecipients.isEmpty());

        // Send Message to users/groups in recipient list
        } else if(ae.getSource() == bSend) {
            try {

                String message = taMessage.getText();

                System.out.println("To: ");
                
                // iterate through list of recipients                
                while (!(dlmRecipients.isEmpty())) {
                    String recipient = (String) dlmRecipients.remove(0);
                    
                    // if recipient is a user, then use sendMessageToUser method
                    if(recipient.startsWith(USER_TAG)) {
                        String user = recipient.substring(USER_TAG.length());
                        System.out.println("user = " + user);

                        // use MessageClient class to send message to MessageServer
                        //  A MessageResponse Object is returned containing an array
                        //  of responses from server
                        MessageResponse uResp 
                            = _messageClient.sendMessageToUser(user, message);
                        String [] uRespMessages = uResp.getResponses();
                        System.out.println("dump response...");
                        for(int j=0; j<uRespMessages.length; j++) {
                            System.out.println(uRespMessages[j]);
                        }
                        System.out.println("...done.");

                    // if recipient is a group, then use sendMessageToGroup method
                    } else if(recipient.startsWith(GROUP_TAG)) {
                        String group = recipient.substring(GROUP_TAG.length());
                        System.out.println("group = " + group);

                        // use MessageClient class to send message to MessageServer
                        //  A MessageResponse Object is returned containing an array
                        //  of responses from server.  There will be a response for
                        //  each individual user within the group.
                        MessageResponse gResp
                            = _messageClient.sendMessageToGroup(group, 
                                                                message);
                        String [] gRespMessages = gResp.getResponses();
                        System.out.println("dump response...");
                        for(int k=0; k<gRespMessages.length; k++) {
                            System.out.println(gRespMessages[k]);
                        }
                        System.out.println("...done.");

                    } else {
                        System.out.println("Unknown recipient : " + recipient);
                    }
                }
                bRemove.setEnabled(false);

                System.out.println("-----");
                System.out.println("Message: ");
                System.out.println(message);
                System.out.println("---------- DONE ----------");
                taMessage.setText("");

            } catch(Exception x) {
                x.printStackTrace();
            }
        }
    } // end of actionPerformed()


    /**
     * Connect with the AdminServer Servlet and obtain a listing of
     * all users, or a listing of all user groups.
     * 
     * This method obtains and passes the users OAT to the AdminServer
     * Servlet.
     *     
     * @param type The type of the list being requested:  AdminServer.ALL_USERS
     * or AdminServer.ALL_USER_GROUPS
     *
     * @return A Vector of Resources containing all of the users or all of the 
     * user groups
     *
     * @exception java.lang.Exception
     */
    Vector getListFromAdminServer(int type) 
        throws Exception
    {
        URL codeBase = getCodeBase();

        URL url = new URL("http://" + codeBase.getHost() 
                          + ":" + codeBase.getPort() 
                          + ADMIN_SERVER_SERVLET_URL);

        int remainingRetries = 3;
        URLConnection conn = null;

        do {
            try {
                conn = url.openConnection();
                conn.setUseCaches(false);
                conn.setDoOutput(true);
                conn.setDoInput(true);

                ObjectOutputStream oos 
                    = new ObjectOutputStream(conn.getOutputStream());

                // Obtain OAT               
                OAT userOat = LoginContext.getDefaultLoginContext().getOAT();

                // Write OAT to AdminServer Servlet
                //  The Servlet could then use the OAT to authenticate the 
                //  Applet user
                oos.writeObject(userOat);
                oos.writeInt(type);

                oos.close();
                remainingRetries = 0;

            } catch(IOException x) {
                remainingRetries--;
                if(remainingRetries <= 0) {
                    System.out.println("Failed to connect!!!");
                    return(null);
                }
            }

        } while(remainingRetries > 0);

        ObjectInputStream ois = new ObjectInputStream(conn.getInputStream());

        return((Vector) ois.readObject());
    }
}
