/*================================================================== 
 * Licensed Materials - Property of IBM 
 * IBM SecureWay On Demand Client/Server 
 * (c) Copyright IBM Corp. 1999  All rights reserved. 
 * 
 * US Government Users Restricted Rights - Use, duplication or 
 * disclosure restricted by GSA ADP Schedule Contract with IBM 
 * Corp. 
 * 
 * DISCLAIMER OF WARRANTIES.  The following [enclosed] code is 
 * sample code created by IBM Corporation.  This sample code is 
 * not part of any standard or IBM product and is provided to you 
 * solely for the purpose of assisting you in the development of 
 * your applications.  The code is provided "AS IS", without 
 * warranty of any kind.  IBM shall not be liable for any damages 
 * arising out of your use of the sample code, even if they have 
 * been advised of the possibility of such damages. 
 ******************************************************************** 
 * PageMartMessenger.java
 *
 * Demo: Pager Messaging 
 *
 * Purpose:
 * The Pager class for PageMart pagers.  It uses the www2.pagemart.com
 * website to send the page.  The class examines the html file returned
 * by the paging cgi program to determine if the page was successful.
 ******************************************************************** 
 * Change History: 
 ******************************************************************** 
 * 
 *  REASON   DATE     ORIGIN     DESCRIPTION 
 *  -------- ------   ------     ----------- 
 *  new      052599   Steve Ims  New code 
 *===================================================================*/ 

package Demos.MessageDemo.MessageServer.server;


import java.io.*;
import java.net.*;
import java.text.*;
import java.util.*;


/**
 * The pager class for PageMart pagers.
 * 
 * @author Steve Ims
 */
public class PageMartMessenger implements PagerMessenger {
    String _pin;


    PageMartMessenger(String pin) {
        _pin = new String(pin);
    }


    public boolean sendPage(String message) {
        try {
            // Send the page ...
            String host = "www2.pagemart.com";
            int port = 80;
            String file = "/cgi-bin/rbox/pglpage-cgi";

            String postString = "pin=" + _pin 
                + "&PAGELAUNCHERID=2"
                + "&failmsg="
                + "&pin1=xxxxxxx"
                + "&message1=" + URLEncoder.encode(message)
                + "&pin2=" + _pin;
                

            StringBuffer buf = new StringBuffer("");
            buf.append("POST /cgi-bin/rbox/pglpage-cgi HTTP/1.1\n");
            buf.append("Accept: image/gif, image/x-xbitmap, image/jpeg, "
                       + "image/pjpeg, application/vnd.ms-excel, "
                       + "application/msword, "
                       + "application/vnd.ms-powerpoint, */*\n");
            buf.append("Accept-Language: en-us\n");
            buf.append("Content-Type: application/x-www-form-urlencoded\n");
            buf.append("Accept-Encoding: gzip, deflate\n");
            buf.append("User-Agent: Mozilla/4.0 (compatible; MSIE 4.01; "
                       + "Windows NT)\n");
            buf.append("Host: " + host + ":" + port + "\n");
            buf.append("Content-Length: " + postString.length() + "\n");
            buf.append("Connection: Keep-Alive\n");
            buf.append("\n");
            buf.append(postString);


            Socket s = new Socket(host, port);
            s.getOutputStream().write(buf.toString().getBytes());

            // Inspect the return page.
            InputStreamReader isr = new InputStreamReader(s.getInputStream());
            BufferedReader br = new BufferedReader(isr);

            buf = new StringBuffer("");
            String line;
            while((line = br.readLine()) != null) {
                buf.append(line);
            }

            String response = buf.toString();

            return(response.indexOf("Your complete message was just "
                                        + "transmitted to") >= 0);
        } catch(Exception x) {
            x.printStackTrace();
            return(false);
        }
    }
}
