/*================================================================== 
 * Licensed Materials - Property of IBM 
 * IBM SecureWay On Demand Client/Server 
 * (c) Copyright IBM Corp. 1999  All rights reserved. 
 * 
 * US Government Users Restricted Rights - Use, duplication or 
 * disclosure restricted by GSA ADP Schedule Contract with IBM 
 * Corp. 
 * 
 * DISCLAIMER OF WARRANTIES.  The following [enclosed] code is 
 * sample code created by IBM Corporation.  This sample code is 
 * not part of any standard or IBM product and is provided to you 
 * solely for the purpose of assisting you in the development of 
 * your applications.  The code is provided "AS IS", without 
 * warranty of any kind.  IBM shall not be liable for any damages 
 * arising out of your use of the sample code, even if they have 
 * been advised of the possibility of such damages. 
 ******************************************************************** 
 * PagerMessengerFactory.java
 *
 * Demo: Pager Messaging 
 *
 * Purpose:
 * Static class used to instantiate the proper Pager class
 ******************************************************************** 
 * Change History: 
 ******************************************************************** 
 * 
 *  REASON   DATE     ORIGIN     DESCRIPTION 
 *  -------- ------   ------     ----------- 
 *  new      052599   Steve Ims  New code 
 *===================================================================*/ 

package Demos.MessageDemo.MessageServer.server;

import Demos.MessageDemo.MessageServer.*;


/**
 * Static class used to determine which Pager class to 
 * instantiate.
 * 
 * @author Steve Ims
 */
public class PagerMessengerFactory {
    // Prevent instantiation.
    private PagerMessengerFactory() {}


    public static PagerMessenger getPagerMessenger(String type, String pin) {
        PagerMessenger messenger = null;

        if(MessageConstants.SUPPORTED_PAGERS[0].equals(type)) {
            // SkyWordPager
            messenger 
                = new SkyTelMessenger(SkyTelMessenger.SKYWORD_PAGER, pin);

        } else if(MessageConstants.SUPPORTED_PAGERS[1].equals(type)) {
            // SkyTel2WayPager
            messenger 
                = new SkyTelMessenger(SkyTelMessenger.SKYTEL_2_WAY_PAGER, pin);

        } else if(MessageConstants.SUPPORTED_PAGERS[2].equals(type)) {
            // SkyWordPlusPager
            messenger 
                = new SkyTelMessenger(SkyTelMessenger.SKYWORD_PLUS_PAGER, pin);

        } else if(MessageConstants.SUPPORTED_PAGERS[3].equals(type)) {
            // PageMartPager
            messenger
                = new PageMartMessenger(pin);
        }

        return(messenger);
    }
}
