/*================================================================== 
 * Licensed Materials - Property of IBM 
 * IBM SecureWay On Demand Client/Server 
 * (c) Copyright IBM Corp. 1999  All rights reserved. 
 * 
 * US Government Users Restricted Rights - Use, duplication or 
 * disclosure restricted by GSA ADP Schedule Contract with IBM 
 * Corp. 
 * 
 * DISCLAIMER OF WARRANTIES.  The following [enclosed] code is 
 * sample code created by IBM Corporation.  This sample code is 
 * not part of any standard or IBM product and is provided to you 
 * solely for the purpose of assisting you in the development of 
 * your applications.  The code is provided "AS IS", without 
 * warranty of any kind.  IBM shall not be liable for any damages 
 * arising out of your use of the sample code, even if they have 
 * been advised of the possibility of such damages. 
 ******************************************************************** 
 * SkyTelMessenger.java
 *
 * Demo: Pager Messaging 
 *
 * Purpose:
 * The Pager class for SkyTel pagers.  It supports 3 different types
 * of SkyTel pagers.  The class examines the html file returned
 * by the paging cgi program to determine if the page was successful.
 ******************************************************************** 
 * Change History: 
 ******************************************************************** 
 * 
 *  REASON   DATE     ORIGIN     DESCRIPTION 
 *  -------- ------   ------     ----------- 
 *  new      052599   Steve Ims  New code 
 *===================================================================*/ 

package Demos.MessageDemo.MessageServer.server;

import java.io.*;
import java.net.*;


/**
 * The pager class for the SkyTel pagers.  The class supports
 * three different types of SkyTel pagers.
 * 
 * @author Steve Ims
 */
public class SkyTelMessenger implements PagerMessenger {
    public final static int SKYWORD_PAGER = 1;
    public final static int SKYTEL_2_WAY_PAGER = 2;
    public final static int SKYWORD_PLUS_PAGER = 4;

    int _type;
    String _pin;


    SkyTelMessenger(int type, String pin) {
        _type = type;
        _pin = new String(pin);
    }


    public boolean sendPage(String message) {
        try {

            // Send the message to the SkyTel server.
            URL url = new URL("http", 
                              "204.71.160.11", 
                              80, 
                              "/destineer/ss_paging.cgi?cmd=send&to=" 
                              + _pin
                              + ","
                              + _type
                              + "&msg=" 
                              + URLEncoder.encode(message));

            InputStream is = url.openStream();


            // Capture the response.
            StringBuffer buf = new StringBuffer("");

            InputStreamReader isr = new InputStreamReader(is);
            BufferedReader br = new BufferedReader(isr);

            String line;
            String eol = System.getProperty("line.separator");
            while((line = br.readLine()) != null) {
                buf.append(line + eol);
            }

            String response = buf.toString();

            return(response.indexOf("The Destineer Messaging Center Has "
                                    + "Received Your Message.") >= 0);

        } catch(Exception x) {
            x.printStackTrace();
            return(false);
        }
    }
}
